pub struct ReportFrontmatterSteering {
pub workflow_phase: Option<String>,
pub mode: Option<String>,
pub skill_code: Option<String>,
pub framework_version: Option<String>,
}Expand description
Small, stable steering metadata that can route retrieval and framework behavior.
Fields
workflow_phase: Option<String>mode: Option<String>skill_code: Option<String>framework_version: Option<String>Trait Implementations
Sourceimpl Clone for ReportFrontmatterSteering
impl Clone for ReportFrontmatterSteering
Sourcefn clone(&self) -> ReportFrontmatterSteering
fn clone(&self) -> ReportFrontmatterSteering
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReportFrontmatterSteering
impl Debug for ReportFrontmatterSteering
Sourceimpl Default for ReportFrontmatterSteering
impl Default for ReportFrontmatterSteering
Sourcefn default() -> ReportFrontmatterSteering
fn default() -> ReportFrontmatterSteering
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReportFrontmatterSteering
impl<'de> Deserialize<'de> for ReportFrontmatterSteering
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReportFrontmatterSteering
Sourceimpl PartialEq for ReportFrontmatterSteering
impl PartialEq for ReportFrontmatterSteering
Sourcefn eq(&self, other: &ReportFrontmatterSteering) -> bool
fn eq(&self, other: &ReportFrontmatterSteering) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReportFrontmatterSteering