pub struct SemanticSegment {
pub repo: Option<RepoIdentity>,
pub source_tier: Option<SourceTier>,
pub kind: Kind,
pub agent: String,
pub session_id: String,
pub entries: Vec<TimelineEntry>,
}Fields
repo: Option<RepoIdentity>source_tier: Option<SourceTier>The trust tier of the strongest signal that produced repo.
None when repo is None.
kind: Kindagent: Stringsession_id: Stringentries: Vec<TimelineEntry>Implementations
Sourceimpl SemanticSegment
impl SemanticSegment
pub fn project_label(&self) -> String
Sourcepub fn has_assertable_identity(&self) -> bool
pub fn has_assertable_identity(&self) -> bool
Whether the repo identity is strong enough for canonical store placement.
Returns false for None repo or Fallback/Opaque tiers.